@@ -10,27 +10,18 @@ test_that("data_check is properly linked", {
   expect_error(pie_bake(a, template = "basic2"), "second variable")
 })
 
-test_that("output has 'list' type", {
-  a <- data.frame(letters[1:3], 1:3)
-  expect_type(pie_bake(a, template = "basic1"), "list")
-  expect_type(pie_bake(a, template = "basic2"), "list")
-  expect_type(pie_bake(a, template = "basic3"), "list")
-  expect_type(pie_bake(a, template = "basic4"), "list")
-  expect_type(pie_bake(a, template = "basic5", title = "tt"), "list")
-})
-
 test_that("output is a 'ggplot' object", {
   a <- data.frame(letters[1:3], 1:3)
-  expect_match(class(pie_bake(a, template = "basic5", perc = T)), "gg")
-  expect_match(class(pie_bake(a, template = "basic4", perc = T)), "gg")
-  expect_match(class(pie_bake(a, template = "basic3", perc = T)), "gg")
-  expect_match(class(pie_bake(a, template = "basic2", perc = T)), "gg")
-  expect_match(class(pie_bake(a, template = "basic1", perc = T)), "gg")
-  expect_match(class(pie_bake(a, template = "bw1", title = "gg")), "gg")
-  expect_match(class(pie_bake(a, template = "bw2", title = "gg")), "gg")
-  expect_match(class(pie_bake(a, template = "bw3", title = "gg")), "gg")
-  expect_match(class(pie_bake(a, template = "bw4", title = "gg")), "gg")
-  expect_match(class(pie_bake(a, template = "bw5", title = "gg")), "gg")
+  expect_true(is_ggplot(pie_bake(a, template = "basic5", perc = T)))
+  expect_true(is_ggplot(pie_bake(a, template = "basic4", perc = T)))
+  expect_true(is_ggplot(pie_bake(a, template = "basic3", perc = T)))
+  expect_true(is_ggplot(pie_bake(a, template = "basic2", perc = T)))
+  expect_true(is_ggplot(pie_bake(a, template = "basic1", perc = T)))
+  expect_true(is_ggplot(pie_bake(a, template = "bw1", title = "gg")))
+  expect_true(is_ggplot(pie_bake(a, template = "bw2", title = "gg")))
+  expect_true(is_ggplot(pie_bake(a, template = "bw3", title = "gg")))
+  expect_true(is_ggplot(pie_bake(a, template = "bw4", title = "gg")))
+  expect_true(is_ggplot(pie_bake(a, template = "bw5", title = "gg")))
 })
 
 test_that("title specification works", {
@@ -85,7 +76,7 @@ test_that("also tibbles can be baked", {
   a <- data.frame(letters[1:3], 1:3)
   b <- tibble::tibble(letters[1:5], 1:5)
   c <- tibble::tibble(letters[1:5], c(4.3, 2.2, 1, 2, 3.0))
-  expect_match(class(pie_bake(tibble::as_tibble(a), template = "blue1")), "gg")
-  expect_match(class(pie_bake(b, template = "blue3")), "gg")
-  expect_match(class(pie_bake(c, template = "blue4")), "gg")
+  expect_true(is_ggplot(pie_bake(tibble::as_tibble(a), template = "blue1")))
+  expect_true(is_ggplot(pie_bake(b, template = "blue3")))
+  expect_true(is_ggplot(pie_bake(c, template = "blue4")))
 })
